@@ -1,5 +1,6 @@
 import logging
 import os
+import py
 import random
 from tempfile import TemporaryDirectory, NamedTemporaryFile
 
@@ -13,7 +14,6 @@ from numpy.testing import assert_array_equal
 LOGGER = logging.getLogger(__name__)
 
 from autofaiss import build_index
-from tests.unit.test_embeddings_iterators import build_test_collection_numpy, build_test_collection_parquet
 
 logging.basicConfig(level=logging.DEBUG)
 
@@ -22,6 +22,55 @@ logging.basicConfig(level=logging.DEBUG)
 logging.getLogger("py4j").setLevel(logging.ERROR)
 
 
+def build_test_collection_numpy(
+    tmpdir: py.path, min_size=2, max_size=10000, dim=512, nb_files=5, tmpdir_name: str = "autofaiss_numpy"
+):
+    tmp_path = tmpdir.mkdir(tmpdir_name)
+    sizes = [random.randint(min_size, max_size) for _ in range(nb_files)]
+    all_arrays = []
+    file_paths = []
+    for i, size in enumerate(sizes):
+        arr = np.random.rand(size, dim).astype("float32")
+        all_arrays.append(arr)
+        file_path = os.path.join(tmp_path, f"{str(i)}.npy")
+        file_paths.append(file_path)
+        np.save(file_path, arr)
+    all_arrays = np.vstack(all_arrays)
+    return str(tmp_path), sizes, dim, all_arrays, file_paths
+
+
+def build_test_collection_parquet(
+    tmpdir: py.path,
+    min_size=2,
+    max_size=10000,
+    dim=512,
+    nb_files=5,
+    tmpdir_name: str = "autofaiss_parquet",
+    consecutive_ids=False,
+):
+    tmp_path = tmpdir.mkdir(tmpdir_name)
+    sizes = [random.randint(min_size, max_size) for _ in range(nb_files)]
+    dim = dim
+    all_dfs = []
+    file_paths = []
+    n = 0
+    for i, size in enumerate(sizes):
+        arr = np.random.rand(size, dim).astype("float32")
+        if consecutive_ids:
+            # ids would be consecutive from 0 to N-1
+            ids = list(range(n, n + size))
+        else:
+            ids = np.random.randint(max_size * nb_files * 10, size=size)
+        df = pd.DataFrame({"embedding": list(arr), "id": ids})
+        all_dfs.append(df)
+        file_path = os.path.join(tmp_path, f"{str(i)}.parquet")
+        df.to_parquet(file_path)
+        file_paths.append(file_path)
+        n += len(df)
+    all_dfs = pd.concat(all_dfs)
+    return str(tmp_path), sizes, dim, all_dfs, file_paths
+
+
 def test_quantize(tmpdir):
     min_size = random.randint(1, 100)
     max_size = random.randint(min_size, 10240)
@@ -132,7 +181,9 @@ def test_quantize_with_pyspark(tmpdir):
     output_parquet_index_faiss = faiss.read_index(index_parquet_path)
     output_parquet_ids = pq.read_table(ids_path).to_pandas()
     assert output_parquet_index_faiss.ntotal == len(expected_df)
-    pd.testing.assert_frame_equal(output_parquet_ids.reset_index(drop=True), expected_df[["id"]].reset_index(drop=True))
+    pd.testing.assert_frame_equal(
+        output_parquet_ids[["id"]].reset_index(drop=True), expected_df[["id"]].reset_index(drop=True)
+    )
 
     tmp_dir, _, _, expected_array, _ = build_test_collection_numpy(
         tmpdir, min_size=min_size, max_size=max_size, dim=dim, nb_files=nb_files
@@ -294,14 +345,12 @@ def test_index_correctness_in_distributed_mode(tmpdir):
 
 
 def _search_from_multiple_indices(index_paths, query, k):
-    n = 0
     all_distances, all_ids, NB_QUERIES = [], [], 1
     for rest_index_file in index_paths:
         index = faiss.read_index(rest_index_file)
         distances, ids = index.search(query, k=k)
         all_distances.append(distances)
-        all_ids.append(ids + n)
-        n += index.ntotal
+        all_ids.append(ids)
 
     dists_arr = np.stack(all_distances, axis=1).reshape(NB_QUERIES, -1)
     knn_ids_arr = np.stack(all_ids, axis=1).reshape(NB_QUERIES, -1)
@@ -316,7 +365,7 @@ def _merge_indices(index_paths):
     merged = faiss.read_index(index_paths[0])
     for rest_index_file in index_paths[1:]:
         index = faiss.read_index(rest_index_file)
-        faiss.merge_into(merged, index, shift_ids=True)
+        faiss.merge_into(merged, index, shift_ids=False)
     return merged
 
 
@@ -332,7 +381,7 @@ def test_index_correctness_in_distributed_mode_with_multiple_indices(tmpdir):
     )
     temporary_indices_folder = os.path.join(tmpdir.strpath, "distributed_autofaiss_indices")
     ids_path = os.path.join(tmpdir.strpath, "ids")
-    index_path2_metric_infos = build_index(
+    _, index_path2_metric_infos = build_index(
         embeddings=tmp_dir,
         distributed="pyspark",
         file_format="parquet",
@@ -348,14 +397,14 @@ def test_index_correctness_in_distributed_mode_with_multiple_indices(tmpdir):
         id_columns=["id"],
     )
     index_paths = sorted(index_path2_metric_infos.keys())
-    K, all_distances, all_ids, NB_QUERIES = 5, [], [], 1
+    K, NB_QUERIES = 5, 1
     query = faiss.rand((NB_QUERIES, dim))
 
     ground_truth_index = faiss.index_factory(dim, "IVF1,Flat", faiss.METRIC_INNER_PRODUCT)
     expected_array = np.stack(expected_df["embedding"])
     ground_truth_index.train(expected_array)
     ground_truth_index.add(expected_array)
-    ground_truth_distances, ground_truth_ids = ground_truth_index.search(query, k=K)
+    _, ground_truth_ids = ground_truth_index.search(query, k=K)
 
     ids_mappings = pd.read_parquet(ids_path)["id"]
     assert len(ids_mappings) == len(expected_df)
@@ -363,7 +412,7 @@ def test_index_correctness_in_distributed_mode_with_multiple_indices(tmpdir):
 
     _, sorted_k_ids = _search_from_multiple_indices(index_paths=index_paths, query=query, k=K)
     merged = _merge_indices(index_paths)
-    distances, ids = merged.search(query, k=K)
+    _, ids = merged.search(query, k=K)
     assert_array_equal(ids, ground_truth_ids)
     assert_array_equal(sorted_k_ids, ground_truth_ids)
 
@@ -373,7 +422,7 @@ def test_index_correctness_in_distributed_mode_with_multiple_indices(tmpdir):
     )
 
     temporary_indices_folder = os.path.join(tmpdir.strpath, "distributed_autofaiss_indices")
-    index_path2_metric_infos = build_index(
+    _, index_path2_metric_infos = build_index(
         embeddings=tmp_dir,
         distributed="pyspark",
         file_format="npy",
@@ -389,12 +438,12 @@ def test_index_correctness_in_distributed_mode_with_multiple_indices(tmpdir):
     ground_truth_index = faiss.index_factory(dim, "IVF1,Flat", faiss.METRIC_INNER_PRODUCT)
     ground_truth_index.train(expected_array)
     ground_truth_index.add(expected_array)
-    ground_truth_distances, ground_truth_ids = ground_truth_index.search(query, k=K)
+    _, ground_truth_ids = ground_truth_index.search(query, k=K)
 
     index_paths = sorted(index_path2_metric_infos.keys())
     _, sorted_k_ids = _search_from_multiple_indices(index_paths=index_paths, query=query, k=K)
 
     merged = _merge_indices(index_paths)
-    distances, ids = merged.search(query, k=K)
+    _, ids = merged.search(query, k=K)
     assert_array_equal(ids, ground_truth_ids)
     assert_array_equal(sorted_k_ids, ground_truth_ids)
